from .evaluator import (
    ModelEvaluator,
    load_hypothesis_from_file,
    load_audio_from_folder,
)
from .dataset import (
    Dataset,
    load_dataset,
    list_datasets,
    get_dataset_info,
    create_dataset_from_json,
)
# 新增：导入语音评测模块
from .speech_evaluator import SpeechEvaluator

__version__ = "0.3.0"

__all__ = [
    # 核心评测器
    "ModelEvaluator",      # 翻译/语义评测 (BLEU, COMET, etc.)
    "SpeechEvaluator",     # 语音质量评测 (UTMOS, WER)

    # 工具函数
    "load_hypothesis_from_file",
    "load_audio_from_folder",

    # 数据集管理
    "Dataset",
    "load_dataset",
    "list_datasets",
    "get_dataset_info",
    "create_dataset_from_json",
]